CallBasicData

Struct CallBasicData 

pub struct CallBasicData {
Show 20 fields pub id: Option<String>, pub url: Option<String>, pub title: Option<String>, pub scheduled: Option<String>, pub started: Option<String>, pub duration: Option<i64>, pub primary_user_id: Option<String>, pub direction: Option<Direction>, pub system: Option<String>, pub scope: Option<Scope>, pub media: Option<Media>, pub language: Option<String>, pub workspace_id: Option<String>, pub sdr_disposition: Option<String>, pub client_unique_id: Option<String>, pub custom_data: Option<String>, pub purpose: Option<String>, pub meeting_url: Option<String>, pub is_private: Option<bool>, pub calendar_event_id: Option<String>,
}
CallBasicData : call’s metadata.

Fields

id: Option<String>

Gong’s unique numeric identifier for the call (up to 20 digits).

url: Option<String>

The URL to the page in the Gong web application where the call is available.

title: Option<String>

The title of the call.

scheduled: Option<String>

Scheduled date and time of the call in the ISO-8601 format (e.g., ‘2018-02-18T02:30:00-07:00’ or ‘2018-02-18T08:00:00Z’, where Z stands for UTC).

started: Option<String>

The date and time when the call was recorded in the ISO-8601 format (e.g., ‘2018-02-18T02:30:00-07:00’ or ‘2018-02-18T08:00:00Z’, where Z stands for UTC).

duration: Option<i64>

The duration of the call, in seconds.

primary_user_id: Option<String>

The primary user ID of the team member who hosted the call.

direction: Option<Direction>

Call direction.

system: Option<String>

The system with which the call was carried out (e.g., WebEx, ShoreTel, etc.).

scope: Option<Scope>

The scope of the call: ‘internal’ if all the participants are from the company, ‘external’ if some participants are not from the company, or ‘unknown’ if the scope is unknown.

media: Option<Media>

Media type

language: Option<String>

The language codes (as defined by ISO-639-2B). E.g., eng, fre, spa, ger, and ita. Also used are und (unsupported language), and zxx (not enough speech content for identification).

workspace_id: Option<String>

Gong’s unique numeric identifier for the call’s workspace (up to 20 digits).

sdr_disposition: Option<String>

The SDR disposition of the call. This can be an automated value provided by the provider, or manually entered by the rep.

client_unique_id: Option<String>

The call’s unique identifier in the origin recording system (typically a telephony recording system). The identifier is provided to Gong during the call creation via the Public API or through telephony systems integrations.

custom_data: Option<String>

Metadata as was provided to Gong during the call creation via the Public API.

purpose: Option<String>

The purpose of the call.

meeting_url: Option<String>

The meeting provider URL on which the web conference was recorded.

is_private: Option<bool>

If the call is private.

calendar_event_id: Option<String>

The Id of the meeting in Google or Outlook Calendar.

Implementations

Source

impl CallBasicData

pub fn new() -> CallBasicData

call’s metadata.