pub struct ExternalSystem {
pub system: Option<System>,
pub objects: Option<Vec<ExternalSystemObject>>,
}Expand description
ExternalSystem : A list of links to external systems such as CRM, Telephony System, Case Management, etc.
Fields
system: Option<System>External system name.
objects: Option<Vec<ExternalSystemObject>>List of objects within the external system.
Implementations
Sourceimpl ExternalSystem
impl ExternalSystem
Sourcepub fn new() -> ExternalSystem
pub fn new() -> ExternalSystem
A list of links to external systems such as CRM, Telephony System, Case Management, etc.