pub struct MultipleUsersWithDates {
pub from_date: String,
pub to_date: String,
pub created_from_date_time: Option<String>,
pub created_to_date_time: Option<String>,
pub user_ids: Option<Vec<String>>,
}Expand description
MultipleUsersWithDates : Filter parameters.
Fields
from_date: StringThe date (in the company’s time zone) from which to list a user’s activity. This value is inclusive. The date should be specified in the following format: YYYY-MM-DD.
to_date: StringThe date (in the company’s time zone) until which to list a user’s activity. This value is exclusive. This value should not exceed the current day. The date should be specified in the following format: YYYY-MM-DD.
created_from_date_time: Option<String>created_to_date_time: Option<String>user_ids: Option<Vec<String>>Set of Gong’s unique numeric identifiers for the users (up to 20 digits).
Implementations
Sourceimpl MultipleUsersWithDates
impl MultipleUsersWithDates
Sourcepub fn new(from_date: String, to_date: String) -> MultipleUsersWithDates
pub fn new(from_date: String, to_date: String) -> MultipleUsersWithDates
Filter parameters.